@@ -9,12 +9,12 @@ A Sphinx Indexer.
 
 from typing import Any, Dict, List, Tuple
 
-from . import rack, patch as pch, std as gl
+from . import rack, patch as pch, glossary as gl
 
 __copyright__ = 'Copyright (C) 2021 @koKekkoh'
 __license__   = 'BSD 2-Clause License'
 __author__    = '@koKekkoh'
-__version__   = '0.12.0'  # 2022-02-24
+__version__   = '0.12.1'  # 2022-02-27
 __url__       = 'https://github.com/KaKkouo/sphindexer'
 
 # ------------------------------------------------------------
